@@ -24,17 +24,21 @@
 #include <sys/time.h>
 #include <sys/resource.h>
 #include <guile/gh.h>
-#include <argp.h>
 #include <ctype.h>
 #include <errno.h>
 #include <config.h>
 #include <glib.h>
 
+#ifdef HAVE_ARGP_H
+#include <argp.h>
+#endif /* HAVE_ARGP_H */
+
 #include "extension.h"
 #include "fh-utils.h"
 #include "yahoo-backend.h"
 #include "interpreter.h"
 #include "freehoo.h"
+#include "compat.h"
 
 /* private members REALLY. extern'ing these variables are strongly
    discouraged. instead use exported methods to access these variables
