@@ -981,36 +981,35 @@ ext_yahoo_login_response (int id, int succ, char *url)
         }
       return;
     }
-  else if (succ == YAHOO_LOGIN_UNAME)
-    {
-      snprintf (buff, sizeof (buff),
-		"Could not log into Yahoo service - username not recognised.  Please verify that your username is correctly typed.");
-    }
-  else if (succ == YAHOO_LOGIN_PASSWD)
-    {
-      snprintf (buff, sizeof (buff),
-		"Could not log into Yahoo service - password incorrect.  Please verify that your password is correctly typed.");
-    }
-  else if (succ == YAHOO_LOGIN_LOCK)
-    {
-      snprintf (buff, sizeof (buff),
-		"Could not log into Yahoo service.  Your account has been locked.\nVisit %s to reactivate it.",
-		url);
-    }
-  else if (succ == YAHOO_LOGIN_DUPL)
-    {
-      snprintf (buff, sizeof (buff),
-		"You have been logged out of the yahoo service, possibly due to a duplicate login.");
-    }
-  else if (succ == YAHOO_LOGIN_SOCK)
-    {
-      snprintf (buff, sizeof (buff), "The server closed the socket.");
-    }
-  else
-    {
-      snprintf (buff, sizeof (buff), "Could not log in, unknown reason: %d.",
-		succ);
-    }
+  else 
+    switch (succ)
+      {
+      case YAHOO_LOGIN_UNAME:
+	snprintf (buff, sizeof (buff),
+		  "Could not log into Yahoo service - username not recognised.  Please verify that your username is correctly typed.");
+	break;
+      case YAHOO_LOGIN_PASSWD:
+	snprintf (buff, sizeof (buff),
+		  "Could not log into Yahoo service - password incorrect.  Please verify that your password is correctly typed.");
+	break;
+      case YAHOO_LOGIN_LOCK:
+	snprintf (buff, sizeof (buff),
+		  "Could not log into Yahoo service.  Your account has been locked.\nVisit %s to reactivate it.", url);
+	break;
+      case YAHOO_LOGIN_DUPL:
+	snprintf (buff, sizeof (buff),
+		  "You have been logged out of the yahoo service, possibly due to a duplicate login.");
+	break;
+      case YAHOO_LOGIN_SOCK:
+	snprintf (buff, sizeof (buff), "The server closed the socket.");
+	break;
+      case 1:
+	snprintf (buff, sizeof (buff), "Could not login, most probably performing scheduled maintenance.");
+	break;
+      default:
+	snprintf (buff, sizeof (buff), "Could not login, unknown reason: %d.",
+		  succ);
+      }
 
   ylad->status = YAHOO_STATUS_OFFLINE;
   PRINTF_MESSAGE ("\n%s\n", buff);
